ll-orasql
=========

Utilities for working with cx_Oracle__.

__ http://www.python.net/crew/atuining/cx_Oracle/


Documentation
-------------

For documentation read the source or the `web pages`__.

__ http://www.livinglogic.de/Python/orasql/

For installation instruction read ``INSTALL.rst`` or the
`installation web page`__.

__ http://www.livinglogic.de/Python/orasql/Installation.html

For a history of ll-orasql and a list of new features in this version,
read ``NEWS.rst`` or the `history web page`__.

__ http://www.livinglogic.de/Python/orasql/History.html

For the license read ``orasql/__init__.py``.


Download
--------

ll-orasql is available from ftp://ftp.livinglogic.de/pub/livinglogic/orasql/

Web pages can be found at http://www.livinglogic.de/Python/orasql/

-- Walter Dörwald <walter@livinglogic.de>
